pytrip package
==============

.. automodule:: pytrip
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    pytrip.res
    pytrip.tripexecuter
    pytrip.utils

Submodules
----------

.. toctree::

   pytrip.ctimage
   pytrip.ctx
   pytrip.cube
   pytrip.ddd
   pytrip.dicomhelper
   pytrip.dos
   pytrip.error
   pytrip.field
   pytrip.file_parser
   pytrip.get_dvh
   pytrip.header
   pytrip.let
   pytrip.paths
   pytrip.raster
   pytrip.util
   pytrip.vdx

